/*******************************************************************************

    Qt Architect

    Copyright (C) 1997-1999 Jeff Harris and Klaus Ebner

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    $Id: DialogWnd.h,v 2.7 2000/04/30 17:09:37 jeff Exp $

*******************************************************************************/


#ifndef DialogWnd_included
#define DialogWnd_included

#include <qaccel.h>
#include <qmainwindow.h>
#include <qmenubar.h>
#include <qstring.h>
#include <qlabel.h>
#include <qlayout.h>

#include "WidgetLayout.h"
#include "WidgetFrame.h"

class Dialog;
class DlgParser;
class ProjectWnd;
class QToolButtton;

class DialogWnd : public QMainWindow
{
    Q_OBJECT

public:
    DialogWnd
    ( 
	Dialog*,
	ProjectWnd *,
	const char* name = NULL 
    );

    virtual ~DialogWnd();

    int DoPropertyDialog( void );
    // show the property dialog

    WidgetLayout *GetLayout();
      
    void CPAvailable( bool );
    // C&P data available or not

    void SetCaption
    (
	const QString&	captionStr
    );
    // Set the caption on the window and the layout window


public slots:

    void Close();
    // close window

    void UpdateScreen( int flags );
    // Update the menus and toolbars according to the flags given.  If the 
    // flag is present, the item is enabled

signals:

    void Closed();
        
private: // methods

    void resizeEvent
    (
	QResizeEvent*	event
    );

    void closeEvent
    (
	QCloseEvent*	event
    );

    void ResetContents( void );
    // clear and reset the dialog

private slots:
         
    void NewButton();
    void NewButtonGroup();
    void NewCheckBox();
    void NewComboBox();
    void NewFrame();
    void NewGrid();
    void NewGroupBox();
    void NewHBox();
    void NewHButtonGroup();
    void NewHGroupBox();
    void NewIconView();
    void NewLCDNumber();
    void NewLabel();
    void NewLineEdit();
    void NewListBox();
    void NewListView();
    void NewMenuBar();
    void NewMultiLineEdit();
    void NewProgressBar();
    void NewPushButton();
    void NewRadioButton();
    void NewScrollBar();
    void NewScrollView();
    void NewSlider();
    void NewSpinBox();
    void NewSplitter();
    void NewTabBar();
    void NewTextView();
    void NewTextBrowser();
    void NewUser();
    void NewVBox();
    void NewVButtonGroup();
    void NewVGroupBox();

    void ViewLayoutMgr();

    void WidgetGeometryChanged( int, int, int, int );

    void WidgetSelected( const QString& widgetName, 
			 const QString& varName );
  void WidgetDeselected();

    void NewModuleWidget( int );
    // Add a new module from the menu bar

    void NewModuleWidget();
    // Add a new module from a tool bar

    void LayoutWndClosed();
    // The layout window was closed

private: // attributes

    WidgetFrame* itsActWidgetWnd;
    // frame to hold the widgets

    WidgetLayout*	itsActLayout;
    // handles the layout of widgets on the window

    QPopupMenu *itsEditMenu;
    // Have to remember it, because we want to disable items inside
          
    int cutMenuId, copyMenuId, pasteMenuId;
    // Menu ids

    int itsAlignMenuId;
    int	itsAlignTopMenuId;
    int	itsAlignBottomMenuId;
    int	itsAlignLeftMenuId;
    int itsAlignRightMenuId;
    int itsAlignWidthMenuId;
    int itsAlignHeightMenuId;
    int	itsAlignSizeMenuId;
    int itsEditRaiseMenuId;
    int itsEditLowerMenuId;
    int itsEditDeleteMenuId;
    int itsEditSizeToFitMenuId;
    int itsViewLayoutMgrMenuId;
    // More menu ids

    QToolButton* itsCutTbId;
    QToolButton* itsCopyTbId;
    QToolButton* itsPasteTbId;
    QToolButton* itsAlignTopTbId;
    QToolButton* itsAlignBottomTbId;
    QToolButton* itsAlignLeftTbId;
    QToolButton* itsAlignRightTbId;
    QToolButton* itsAlignWidthTbId;
    QToolButton* itsAlignHeightTbId;
    QToolButton* itsAlignSizeTbId;
    // Toolbar ids
 
    QAccel	itsKbdAccel;
    // keyboard accelerator handlers

    QLabel*	itsStatusWidgetLabel;
    // Label for showing the name of the selected widget in the status
    // bar.

    QLabel*	itsStatusPosLabel;
    // Label for showing the position of the selected widget in the
    // status bar.

    QLabel*	itsStatusSizeLabel;
    // Label for showing the size of the selected widget in the status
    // bar.

    ProjectWnd *theProjectWnd;
    // The application

    Dialog *itsDialog;
    // Its master class
};

    
typedef QList<DialogWnd> DlgList;


inline WidgetLayout *DialogWnd::GetLayout()
{
    return itsActLayout;
}


inline void DialogWnd::SetCaption
(
    const QString&	captionStr
)
{
    setCaption( "Qt Architect: " + captionStr );
    setIconText( caption() );
    itsActLayout->SetCaption( captionStr );
}


#endif // DialogWnd_included


