%{
#include <qstring.h>
#include <qregexp.h>
#include "DlgParser.h"
%}

CHARS [A-Za-z_]
WORD {CHARS}({CHARS}|[0-9]|"-"|".")*
WIDGETNAME {CHARS}({CHARS}|[0-9]|"_")*
NUMBER [0-9]+
WIDGETS_A Button|ButtonGroup|CheckBox|ComboBox|Frame|GroupBox
WIDGETS_B LCDNumber|Label|LineEdit|ListBox|MenuBar|PushButton
WIDGETS_C RadioButton|ScrollBar|MultiLineEdit|User|Slider|ProgressBar
WIDGETS_D SpinBox|Splitter|TabBar|ScrollView|ListView|HBox|VBox|Grid
WIDGETS_E TextView|TextBrowser|HButtonGroup|VButtonGroup
MODULEWIDGETS {WIDGETNAME}::{WIDGETNAME}
WIDGETLAYOUT    WidgetLayout
PROJECT   Project
DIALOG    Dialog
PIXMAP    Pixmap
WIDGETS {WIDGETS_A}|{WIDGETS_B}|{WIDGETS_C}|{WIDGETS_D}|{WIDGETS_E}|{MODULEWIDGETS}
ID {NUMBER}("."{NUMBER})*
LAYOUTITEMNAMES1 No_Layout|Box_Layout|Box_Spacing|Box_Stretch
LAYOUTITEMNAMES2 Grid_Layout|Grid_Row|Grid_Spacer|Layout_Widget
LAYOUTITEMNAMES {LAYOUTITEMNAMES1}|{LAYOUTITEMNAMES2}
LAYOUTITEMS {LAYOUTITEMNAMES}-{ID}
%x InsideLayout
%x InsideWidget
%x InsideDialog
%x InsideProject
%x InsideLayoutItem
%x InsidePixmap

%%
%{
%}

<*>[ \t]*  /* Whitespaces are ignored */
<*>\n { 
  if( gDlgParser )
    gDlgParser->lineNumber++; 
}

{PROJECT} {
  // Skipping Whitespaces up to (and including) opening bracket
  int c;
  while( (c = yyinput()) != '{' && c != EOF );

  // Not really a widget, but handled as one for now
  BEGIN(InsideProject);

  return (int) ProjectDataStart;
}

{DIALOG} { 
  if( gDlgParser )
    gDlgParser->widgetType = yytext;

  // Skipping Whitespaces up to (and including) opening bracket
  int c;
  while( (c = yyinput()) != '{' && c != EOF );

  // Not really a widget, but handled as one for now
  BEGIN(InsideDialog);

  return (int) DialogDataStart;
}

{WIDGETLAYOUT} { 
  if( gDlgParser )
    gDlgParser->widgetType = yytext;

  // Skipping Whitespaces up to (and including) opening bracket
  int c;
  while( (c = yyinput()) != '{' && c != EOF );

  BEGIN(InsideLayout);

  return (int) LayoutDataStart;
}

{PIXMAP} { 
  // Skipping Whitespaces up to (and including) opening bracket
  int c;
  while( (c = yyinput()) != '{' && c != EOF );

  BEGIN(InsidePixmap);

  return (int) PixmapDataStart;
}

<InsideLayout>{WIDGETS} { 

    // Monster HACK!!!!!!!!!!!!!!!!  There are two items named Grid.  One is
    // the grid size for the WidgetLayout, the other is for a Grid widget.
    // The file will always have the grid size, and it will always be before
    // the widget.  So, if we catch it here and we haven't seen it yet, do
    // what normally would have been done.  Otherwise, do the normal new
    // widget processing.
    if( gDlgParser->gridSizeSeen )
    {
        if( gDlgParser )
            gDlgParser->widgetType = yytext;

        // Skipping Whitespaces up to (and including) opening bracket
        int c;
        while( (c = yyinput()) != '{' && c != EOF );

        BEGIN(InsideWidget);

        return (int) WidgetDataStart;
    }
    else
    {
        if( gDlgParser )
        {
            gDlgParser->gridSizeSeen = TRUE;
            gDlgParser->key = yytext;
        }

        // Skipping Whitespaces up to opening bracket
        int c;
        while( (c = yyinput()) != '{' && c != EOF );
        unput( c );
    }
}

<InsideLayout>{LAYOUTITEMS} {
  if( gDlgParser )
    gDlgParser->widgetType = yytext;

  // Skipping Whitespaces up to (and including) opening bracket
  int c;
  while( (c = yyinput()) != '{' && c != EOF );

  BEGIN(InsideLayoutItem);

  return (int) LayoutItemDataStart;
}

\{ { 
  fprintf( stderr, "Error in line %d\n", gDlgParser->lineNumber );
  if( gDlgParser )
    gDlgParser->errorCount++;
  return (int) ErrorInInput;
}

<InsidePixmap>\} {
  BEGIN(0);
  return (int) PixmapDataEnd;
}

<InsideWidget>\} {
  BEGIN(InsideLayout);
  return (int) WidgetDataEnd;
}

<InsideLayoutItem>\} {
  BEGIN(InsideLayout);
  return (int) LayoutItemDataEnd;
}

<InsideLayout>\} {
  BEGIN(0);
  return (int) LayoutDataEnd;
}

<InsideDialog>\} {
  BEGIN(0);
  return (int) DialogDataEnd;
}

<InsideProject>\} {
  BEGIN(0);
  return (int) ProjectDataEnd;
}

<*>{WORD} {
  if( gDlgParser )
    gDlgParser->key = yytext;

  // Skipping Whitespaces up to opening bracket
  int c;
  while( (c = yyinput()) != '{' && c != EOF );
  unput( c );
}

<*>\{[^}]*\} {
  QString str( yytext );
  // Removing tabs and newlines
  str.replace( QRegExp( "\n" ), " " );
  str.replace( QRegExp( "\t" ), " " );

  // Removing leading and trailing curly bracket
  str = str.mid( 1, str.length() - 2 );

  if( gDlgParser )
    gDlgParser->value = str;

  int retVal;
  switch( YY_START )
  {  
case InsideDialog : retVal = (int) DialogData; break;
case InsideLayout : retVal = (int) LayoutData; break;
case InsideWidget : retVal = (int) WidgetData; break;
case InsideProject: retVal = (int) ProjectData; break;
case InsideLayoutItem: retVal = (int) LayoutItemData; break;
case InsidePixmap : retVal = (int) PixmapData; break;
default          : retVal = (int) ErrorInInput; break;
  }
  return retVal;
}

    
%%






