/*******************************************************************************

    Qt Architect

    Copyright (C) 1997-1999 Jeff Harris and Klaus Ebner

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    $Id: ProjectWnd.h,v 2.3 2000/04/22 00:57:51 jeff Exp $

*******************************************************************************/


#ifndef ProjectWnd_included
#define ProjectWnd_included

#include <qstring.h>
#include <qmainwindow.h>

#include "appconf.h"
#include "Dialog.h"
#include "Project.h"
#include "ObjectList.h"

class DlgParser;
class Project;
class QToolButton;

class ProjectWnd : public QMainWindow
{
    Q_OBJECT

public:
    ProjectWnd
    ( 
	QWidget* parent = NULL, 
	const char* name = NULL 
	);

    virtual ~ProjectWnd();

    bool IsAutoGenerating( void );
    // true if program is automatically generating

    DlgObject *ObjectLoad( const QString &, Project * = NULL );
    // Load the object

    void FileOpen( const QString& filename );
    // open this dialog

    void ProjectOpen( const QString& filename );
    // open this project

    void SetTempFile( const QString & );
    // Set the c&p working file (used by main.cpp)

    QString &GetCPBuffer();
    // Get the actual contents of the c&p buffer 

    QString GetCPFileName();
    // retrieve the temp. filename where we buffer the c&p data

    static AppConfig& GetAppConfig();
    // Get the global config settings.

signals:
void CPBufferAvailable( bool );

public slots:
    void NewCPBuffer( DlgObject * );
    // Could be used to notify when a subwindow puts st into the cpBuffer

protected: // methods

    void closeEvent( QCloseEvent*   event );
    // Close event

private: // methods

    void ResetContents( void );
    // clear and reset the project

    void LoadDialog( Dialog & );
    // loads the project from the file

    void SaveDialog( Dialog & );
    // save the project to the file

    DlgObject *CreateNewObject( DlgObjectType );
    // Create a new Object

    void ProcessNewObject( DlgObject *obj );
    // Things to do after creating or loading an object
  
    void ObjectOpen( DlgObjectType );
    // Opens an existing Object

    void Update( void );
    // called when the display is updated

private slots:

void ObjectSave();
    void ObjectGenerate();

    void DialogNew();
    void DialogOpen();
    void PixmapNew();
    void PixmapOpen();
    void ProjectNew();
    void ProjectOpen();

    void EditPreferences();

    void ClipBoardChanged();

    void Closed( DlgObject * );
    void Delete( DlgObject * );

    void ProcessCommandArgs();

    void quit();

private: // attributes

    QPopupMenu *windowMenu;
    // the window menu

    QList<DlgObject> itsObjects;
    // All the dialogs

    DlgParser *itsParser;
    // The Parser object which read the input for FileOpen

    QString	itsDlgFilename;
    // filename of the dialog

    ObjectList* itsObjectList;
    // Visible list of loaded objects

    enum PopupEntryId {
	IDDlgSave,
	IDDlgSaveAs,
	IDDlgClose,
	IDDlgRaise,
	IDPrjRename,
	IDPrjSave,
	IDPrjSaveAs,
	IDPrjClose,
	IDPrjAddDlg,
	IDPrjGenDlg,
	IDDlgPrjSave,
	IDDlgPrjSaveAs,
	IDDlgPrjRaise,
	IDDlgPrjRemove,
	IDClsDlgPrjOpen,
	IDClsDlgPrjRemove,
	IDLastList
    };

    int popupIds[IDLastList];
    // The ids of all popup entries

    QToolButton*	itsNewProjectButton;
    QToolButton*	itsNewDialogButton;
    QToolButton*	itsNewPixmapButton;
    QToolButton*	itsSaveAllButton;
    QToolButton*	itsGenerateButton;
    QToolButton*	itsGenerateProjectButton;
    // toolbar buttons

    friend class Project;

    friend class DialogList;

    bool	autoGenerate;
    // flag to tell if you should automatically generate from command line
  
    QString tempFile;
    // The temp. file used by c&p

    QString cpBuffer;
    // The actual cut & paste buffer

    static AppConfig	itsConfig;
    // The global configuration settings
};

inline void ProjectWnd::SetTempFile( const QString &tf )
{
  tempFile = tf;
}

inline QString & ProjectWnd::GetCPBuffer( )
{
  return cpBuffer;
}


inline bool ProjectWnd::IsAutoGenerating( void )
{
    return autoGenerate;
}


inline AppConfig& ProjectWnd::GetAppConfig()
{
    return itsConfig;
}


#endif // ProjectWnd_included


