/*******************************************************************************

    Qt Architect

    Copyright (C) 1997-1999 Jeff Harris and Klaus Ebner

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    $Id: GridSpacer.cpp,v 2.5 2000/04/29 20:15:46 klaus Exp $

*******************************************************************************/


#include "layout/GridSpacer.h"
#include "layout/GridSpacerPropPage.h"
#include "layout/LayoutHelper.h"

#include "xml/QtArchGenerator.h"

#define Inherited LayoutItem

GridSpacer::GridSpacer(
    LayoutItem*	theParent
    )
    :
    Inherited( LayoutItem::LI_GridSpacer, 
	       theParent,
	       GetTreeLabel(), 
	       &PixmapFactory::GetPixmap( GridSpacer_bmp ) )
{
}


GridSpacer::GridSpacer(
    QListView*	theParent
    )
    :
    Inherited( LayoutItem::LI_GridSpacer, 
	       theParent,
	       GetTreeLabel(), 
	       &PixmapFactory::GetPixmap( GridSpacer_bmp ) )
{
}


GridSpacer::~GridSpacer()
{
}


LayoutItemPropPage* GridSpacer::GetPropertyPage( 
    QWidget*		parent,
    bool		/*topLevel*/,
    const WidgetLayout&	/*theWidgetLayout*/
    )
{
    return new GridSpacerPropPage( this,                                         parent );
}


void GridSpacer::AddToLayout( QGridLayout*	/*theGridLayout*/,
			      int		/*theRowNum*/,
			      int		/*theColNum*/ )
{
    // Do nothing, we're just blank space
}


void GridSpacer::SaveContents( QtArchGenerator &generator ) const
{
  generator.WriteStartBlock( Type2String() );

    // No properties

  generator.WriteEndBlock();
}


bool GridSpacer::RestoreKeyValue( const QString&	/*theKey*/,
				  const QString&	/*theValue*/,
				  const DlgWidget*	/*theDlgWidget*/ )
{
    // No properties
    
    return FALSE;
}

void GridSpacer::Restore( const XMLValue &value, LayoutHelper */*helper*/ )
{
  // Sanity check
  if( value.GetTypeString() != Type2String() )
    return;

  //  XMLValueMap map = value.AsNested();
  
}


void GridSpacer::GenerateSourceInGrid( QTextStream&	/*theStream*/,
				       const QString&	/*theLayoutVarName*/,
				       const QString&	/*theLayoutId*/,
				       unsigned int	/*theRowNum*/,
				       unsigned int	/*theColNum*/,
				       const QString&	/*theLayoutParentWidget*/ ) const
{
    // No source to generate
}


QString GridSpacer::GetTreeLabel()
{
    static QString treeLabel = QObject::tr( "Grid Spacer" );
    return treeLabel;
}
