/*******************************************************************************

    Qt Architect

    Copyright (C) 1997-1999 Jeff Harris and Klaus Ebner

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    $Id: DlgKProgress.cpp,v 2.2 1999/10/16 01:46:04 jeff Exp $

*******************************************************************************/


#include "DlgKProgress.h"

#ifndef MODULE_BOOTSTRAP
#include "KProgressPropPage.h"
#endif // MODULE_BOOTSTRAP

#include "GuiTools.h"

#define Inherited DlgFrame

QStrList DlgKProgress::itsSignals;
int DlgKProgress::itsNextWidgetNum = 1;

DlgKProgress::DlgKProgress() :
    Inherited( DlgWidget::DW_Frame )
{
}


DlgKProgress::DlgKProgress(
    DlgWidget::Type	theType
    ) :
    Inherited( theType )
{
}


DlgKProgress::~DlgKProgress()
{
}


void DlgKProgress::GetPropertyPages(
    QWidget*		parent,
    QList<QWidget>&	pages,
    QStrList&		labels
    )
{
    Inherited::GetPropertyPages( parent, pages, labels );

#ifndef MODULE_BOOTSTRAP
    pages.append( new KProgressPropPage( this, parent, "KProgress" ) );

    labels.append( "KProgress" );
#endif // MODULE_BOOTSTRAP
}


void DlgKProgress::SaveContents(
    QTextStream&	stream,
    bool		topLevel
    )
{
    if( topLevel )
    {
	stream << "KDE::KProgress {" << endl;
    }
  
    KProgress* widget = GetKProgress();

    stream << saveIndent << "BarStyle {" 
	   << barStyleToStr( widget->barStyle() ) << "}" << endl;
    
    stream << saveIndent << "Orientation {"
	   << orientationToStr( widget->orientation() ) << "}" << endl;
    
    stream << saveIndent << "BarColor {" 
	   << widget->barColor().rgb() << "}" << endl;
    
    stream << saveIndent << "TextEnabled {";
    SaveBool( stream, widget->textEnabled() );
    stream << "}" << endl;
    
    stream << saveIndent << "Value {" << widget->value() << "}" << endl;
    stream << saveIndent << "LineStep {" << widget->lineStep() << "}" << endl;
    stream << saveIndent << "PageStep {" << widget->pageStep() << "}" << endl;
    stream << saveIndent << "MinValue {" << widget->minValue() << "}" << endl;
    stream << saveIndent << "MaxValue {" << widget->maxValue() << "}" << endl;

    Inherited::SaveContents( stream, FALSE );

    if( topLevel )
    {
	stream << "}" << endl;
    }
}


bool DlgKProgress::RestoreKeyValue( 
    const QString& 	key, 
    const QString& 	value,
    bool		topLevel
    )
{
    bool retVal = TRUE;

    if( topLevel )
    {
	if( key == "Name" )
	{
	    // Update the widget number so that no duplicate names are created
	    UpdateNextWidgetNumber( value, itsNextWidgetNum );
	}
    }

    KProgress* widget = GetKProgress();

    // Compare to known keys
    if( key == "BarStyle" )
    {
	widget->setBarStyle( strToBarStyle( value ) );
    }
    else if( key == "Orientation" )
    {
	widget->setOrientation( strToOrientation( value ) );
    }
    else if( key == "BarColor" )
    {
	widget->setBarColor( QColor( QRgb( value.toUInt() ) ) );
    }
    else if( key == "TextEnabled" )
    {
	widget->setTextEnabled( (value == "TRUE") );
    }
    else if( key == "Value" )
    {
	widget->setValue( value.toInt() );
    }
    else if( key == "LineStep" )
    {
	widget->setSteps( value.toInt(), widget->pageStep() );
    }
    else if( key == "PageStep" )
    {
	widget->setSteps( widget->lineStep(), value.toInt() );
    }
    else if( key == "MinValue" )
    {
	widget->setRange( value.toInt(), widget->maxValue() );
    }
    else if( key == "MaxValue" )
    {
	widget->setRange( widget->minValue(), value.toInt() );
    }
    else
    {
	retVal = Inherited::RestoreKeyValue( key, value, FALSE );
    }

    return retVal;
}


void DlgKProgress::GenerateSource(
    QTextStream&		stream,
    const QString&		varName,
    const QList<DlgWidget>&	zOrdering
    )
{
    Inherited::GenerateSource( stream, varName, zOrdering );

    const KProgress* widget = GetKProgress();

    stream << varName << "setBarStyle( KProgress::"
	   << barStyleToStr( widget->barStyle() ) << " );" << endl;
    
    stream << varName << "setOrientation( KProgress::"
	   << orientationToStr( widget->orientation() ) << " );" << endl;
    
    stream << varName << "setBarColor( QColor( QRgb( "
	   << widget->barColor().rgb() << " ) ) );" << endl;
    
    stream << varName << "setTextEnabled( "
	   << (widget->textEnabled() ? "TRUE" : "FALSE") << " );" << endl;
    
    stream << varName << "setValue( " << widget->value() << " );" << endl;
    
    stream << varName << "setSteps( "
	   << widget->lineStep() << ", " 
	   << widget->pageStep() << " );" << endl;
    
    stream << varName << "setRange( "
	   << widget->minValue() << ", "
	   << widget->maxValue() << " );" << endl;
}


void DlgKProgress::AddSignalsToList( 
    QStrList&	signalList 
    ) const
{
    Inherited::AddSignalsToList( signalList );
    GuiTools::QStrListAppendAll( signalList, GetSignalList() );
}


const QStrList& DlgKProgress::GetSignalList()
{
    if( itsSignals.isEmpty() )
    {
	itsSignals.append( "percentageChanged(int)" );
    }

    return itsSignals;
}


void DlgKProgress::CreateQtWidget(
    QWidget*	theParent,
    const char*	theName
    )
{
    KProgress* widget = 
	new KProgress( theParent,
		       CreateName( "KProgress", 
				   theName, 
				   itsNextWidgetNum ) );

    SetQtWidget( widget, theParent );
}


QString DlgKProgress::barStyleToStr(
    KProgress::BarStyle	theStyle
    )
{
    QString str;
    
    switch( theStyle )
    {
	case KProgress::Solid:
	{
	    str = "Solid";
	    break;
	}
	case KProgress::Blocked:
	{
	    str = "Blocked";
	    break;
	}
    }
    
    return str;
}

    
KProgress::BarStyle DlgKProgress::strToBarStyle(
    const QString&	theStyleStr
    )
{
    KProgress::BarStyle style = KProgress::Solid;
    
    if( theStyleStr == "Solid" )
    {
	style = KProgress::Solid;
    }
    else if( theStyleStr == "Blocked" )
    {
	style = KProgress::Blocked;
    }
    
    return style;
}

    
QString DlgKProgress::orientationToStr(
    KProgress::Orientation	theOrientation
    )
{
    QString str;
    
    switch( theOrientation )
    {
	case KProgress::Horizontal:
	{
	    str = "Horizontal";
	    break;
	}
	case KProgress::Vertical:
	{
	    str = "Vertical";
	    break;
	}
    }
    
    return str;
}

    
KProgress::Orientation DlgKProgress::strToOrientation(
    const QString&	theOrientationStr
    )
{
    KProgress::Orientation orient = KProgress::Horizontal;
    
    if( theOrientationStr == "Horizontal" )
    {
	orient = KProgress::Horizontal;
    }
    else if( theOrientationStr == "Vertical" )
    {
	orient = KProgress::Vertical;
    }
    
    return orient;
}

