/*******************************************************************************

    Qt Architect

    Copyright (C) 1997-1999 Jeff Harris and Klaus Ebner

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    $Id: DialogWindowPage.cpp,v 2.1 1999/10/16 01:48:35 jeff Exp $

*******************************************************************************/


#include "DialogWindowPage.h"

#include "Dialog.h"

#define Inherited DialogWindowPageData

DialogWindowPage::DialogWindowPage
(
    Dialog* dialog,
    QWidget* parent,
    const char* name
)
    :
    Inherited( parent, name )
{
    itsCaption->setText( dialog->GetCaption() );

    WFlags flags = dialog->GetWindowFlags();

    isNormalBorder->setChecked( flags & WStyle_NormalBorder );
    isDialogBorder->setChecked( flags & WStyle_DialogBorder );
    isNoBorder->setChecked( flags & WStyle_NoBorder );
    isStyleTitle->setChecked( flags & WStyle_Title );
    isStyleSysMenu->setChecked( flags & WStyle_SysMenu );
    isStyleMin->setChecked( flags & WStyle_Minimize );
    isStyleMax->setChecked( flags & WStyle_Maximize );
    isStyleToolWnd->setChecked( flags & WStyle_Tool );	
}


DialogWindowPage::~DialogWindowPage()
{
}


void DialogWindowPage::Apply( Dialog* dialog )
{
    dialog->SetCaption( itsCaption->text() );

    unsigned int flags = 0;
    
    if( isNormalBorder->isChecked() )
    {
	flags |= WStyle_NormalBorder;
    }

    if( isDialogBorder->isChecked() )
    {
	flags |= WStyle_DialogBorder;
    }
    
    if( isNoBorder->isChecked() )
    {
	flags |= WStyle_NoBorder;
    }
    
    if( isStyleTitle->isChecked() )
    {
	flags |= WStyle_Title;
    }
    
    if( isStyleSysMenu->isChecked() )
    {
	flags |= WStyle_SysMenu;
    }
    
    if( isStyleMin->isChecked() )
    {
	flags |= WStyle_Minimize;
    }
    
    if( isStyleMax->isChecked() )
    {
	flags |= WStyle_Maximize;
    }
    
    if( isStyleToolWnd->isChecked() )
    {
	flags |= WStyle_Tool;
    }

    // add the custimized flag if any of the others were set, or if NoBorder
    // is set since its value is 0
    if( (flags != 0) || isNoBorder->isChecked() )
    {
	flags |= WStyle_Customize;
    }
        
    dialog->SetWindowFlags( static_cast<Qt::WidgetFlags>(flags) );
}
