/*******************************************************************************

    Qt Architect

    Copyright (C) 1997-1999 Jeff Harris and Klaus Ebner

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    $Id: IconViewPage.cpp,v 2.3 2000/04/30 17:09:40 jeff Exp $

*******************************************************************************/


#include <qiconview.h>
#include <qlist.h>

#include "IconViewPage.h"

#include "widget/DlgIconView.h"

#define Inherited IconViewPageData

IconViewPage::IconViewPage
(
    DlgWidget* widget,
    QWidget* parent,
    const char* name
)
    :
    Inherited( parent, name )
{
    QIconView* iconView = (QIconView*)widget->GetWidget();
    
    switch( iconView->selectionMode() )
    {
        case QIconView::Single:
        {
            isSelectionModeSingle->setChecked( TRUE );
            break;
        }
        case QIconView::Multi:
        {
            isSelectionModeMulti->setChecked( TRUE );
            break;
        }
        case QIconView::Extended:
        {
            isSelectionModeExtended->setChecked( TRUE );
            break;
        }
        case QIconView::NoSelection:
        {
            isSelectionModeNone->setChecked( TRUE );
            break;
        }
    }
    
    switch( iconView->itemTextPos() )
    {
        case QIconView::Bottom:
        {
            isItemTextPosBottom->setChecked( TRUE );
            break;
        }
        case QIconView::Right:
        {
            isItemTextPosRight->setChecked( TRUE );
            break;
        }
    }
    
    switch( iconView->arrangement() )
    {
        case QIconView::LeftToRight:
        {
            isArrangementLeftToRight->setChecked( TRUE );
            break;
        }
        case QIconView::TopToBottom:
        {
            isArrangementTopToBottom->setChecked( TRUE );
            break;
        }
    }
    
    switch( iconView->resizeMode() )
    {
        case QIconView::Fixed:
        {
            isResizeModeFixed->setChecked( TRUE );
            break;
        }
        case QIconView::Adjust:
        {
            isResizeModeAdjust->setChecked( TRUE );
            break;
        }
    }
    
    itsGridX->setText( QString::number( iconView->gridX() ) );
    itsGridY->setText( QString::number( iconView->gridY() ) );
    itsMaxItemWidth->setText( QString::number( iconView->maxItemWidth() ) );
    itsMaxItemTextLength->setText( QString::number( iconView->maxItemTextLength() ) );
    
    isSorting->setChecked( iconView->sorting() );
    sortingToggled( isSorting->isChecked() );
    isSortAscending->setChecked( iconView->sortDirection() );
    isWordWrapIconText->setChecked( iconView->wordWrapIconText() );
    isItemsMovable->setChecked( iconView->itemsMovable() );
    isAutoArrange->setChecked( iconView->autoArrange() );
    isShowToolTips->setChecked( iconView->showToolTips() );
}


IconViewPage::~IconViewPage()
{
}


void IconViewPage::Apply( DlgWidget*	widget )
{
    QIconView* iconView = (QIconView*)widget->GetWidget();

    QIconView::SelectionMode selMode = QIconView::Single;
    if( isSelectionModeSingle->isChecked() )
    {
        selMode = QIconView::Single;
    }
    else if( isSelectionModeMulti->isChecked() )
    {
        selMode = QIconView::Multi;
    }
    else if( isSelectionModeExtended->isChecked() )
    {
        selMode = QIconView::Extended;
    }
    else if( isSelectionModeNone->isChecked() )
    {
        selMode = QIconView::NoSelection;
    }
    iconView->setSelectionMode( selMode );
    
    QIconView::ItemTextPos pos = QIconView::Bottom;
    if( isItemTextPosBottom->isChecked() )
    {
        pos = QIconView::Bottom;
    }
    else if( isItemTextPosRight->isChecked() )
    {
        pos = QIconView::Right;
    }
    iconView->setItemTextPos( pos );
    
    QIconView::Arrangement arrangement = QIconView::LeftToRight;
    if( isArrangementLeftToRight->isChecked() )
    {
        arrangement = QIconView::LeftToRight;
    }
    else if( isArrangementTopToBottom->isChecked() )
    {
        arrangement = QIconView::TopToBottom;
    }
    iconView->setArrangement( arrangement );
    
    QIconView::ResizeMode resizeMode = QIconView::Fixed;
    if( isResizeModeFixed->isChecked() )
    {
        resizeMode = QIconView::Fixed;
    }
    else if( isResizeModeAdjust->isChecked() )
    {
        resizeMode = QIconView::Adjust;
    }
    iconView->setResizeMode( resizeMode );
    
    iconView->setGridX( itsGridX->text().toInt() );
    iconView->setGridY( itsGridY->text().toInt() );
    iconView->setMaxItemWidth( itsMaxItemWidth->text().toInt() );
    iconView->setMaxItemTextLength( itsMaxItemTextLength->text().toInt() );
    
    iconView->setSorting( isSorting->isChecked(), isSortAscending->isChecked() );
    iconView->setWordWrapIconText( isWordWrapIconText->isChecked() );
    iconView->setItemsMovable( isItemsMovable->isChecked() );
    iconView->setAutoArrange( isAutoArrange->isChecked() );
    iconView->setShowToolTips( isShowToolTips->isChecked() );

    DlgIconView* dlgIconView = static_cast<DlgIconView*>(widget);
    dlgIconView->AddDemoItems();
}

void IconViewPage::sortingToggled( bool on )
{
    isSortAscending->setEnabled( on );
}
