/*******************************************************************************

    Qt Architect

    Copyright (C) 1997-1999 Jeff Harris and Klaus Ebner

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    $Id: LCDNumberPage.cpp,v 2.2 2000/04/30 17:09:41 jeff Exp $

*******************************************************************************/


#include <qlcdnum.h>
#include <qstring.h>

#include "LCDNumberPage.h"

#include "widget/DlgLCDNumber.h"
#include "widget/DlgWidget.h"

#define Inherited LCDNumberPageData

LCDNumberPage::LCDNumberPage
(
    DlgWidget* widget,
    QWidget* parent,
    const char* name
)
    :
    Inherited( parent, name )
{
    DlgLCDNumber* lcdNumber = (DlgLCDNumber*)widget;
    QLCDNumber* num = (QLCDNumber*)lcdNumber->GetWidget();
    QString str;
    
    switch( num->mode() )
    {
	case QLCDNumber::HEX:
	{
	    isModeHex->setChecked( TRUE );
	    break;
	}
	case QLCDNumber::DEC:
	{
	    isModeDecimal->setChecked( TRUE );
	    break;
	}
	case QLCDNumber::OCT:
	{
	    isModeOctal->setChecked( TRUE );
	    break;
	}
	case QLCDNumber::BIN:
	{
	    isModeBinary->setChecked( TRUE );
	    break;
	}
    }

    switch( num->segmentStyle() )
    {
	case QLCDNumber::Outline:
	{
	    isSegmentOutline->setChecked( TRUE );
	    break;
	}
	case QLCDNumber::Filled:
	{
	    isSegmentFilled->setChecked( TRUE );
	    break;
	}
	case QLCDNumber::Flat:
	{
	    isSegmentFlat->setChecked( TRUE );
	    break;
	}
    }

    str.setNum( num->numDigits() );
    itsValue->setText( lcdNumber->GetValue() );
    itsNumDigits->setText( str );
    isSmallPoint->setChecked( num->smallDecimalPoint() );
}


LCDNumberPage::~LCDNumberPage()
{
}


void LCDNumberPage::Apply( DlgWidget*	widget )
{
    DlgLCDNumber* lcdNumber = (DlgLCDNumber*)widget;
    QLCDNumber* num = (QLCDNumber*)lcdNumber->GetWidget();
    
    QLCDNumber::Mode mode = QLCDNumber::DEC;

    if( isModeHex->isChecked() )
    {
	mode = QLCDNumber::HEX;
    }
    else if( isModeOctal->isChecked() )
    {
	mode = QLCDNumber::OCT;
    }
    else if( isModeBinary->isChecked() )
    {
	mode = QLCDNumber::BIN;
    }
    
    num->setMode( mode );

    QLCDNumber::SegmentStyle style = QLCDNumber::Outline;
    
    if( isSegmentFilled->isChecked() )
    {
	style = QLCDNumber::Filled;
    }
    else if( isSegmentFlat->isChecked() )
    {
	style = QLCDNumber::Flat;
    }

    num->setSegmentStyle( style );

    lcdNumber->SetValue( itsValue->text() );
    QString str = itsNumDigits->text();
    num->setNumDigits( str.toInt() );
    num->setSmallDecimalPoint( isSmallPoint->isChecked() );
}

    
    
