/*******************************************************************************

    Qt Architect

    Copyright (C) 1997-1999 Jeff Harris and Klaus Ebner

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    $Id: SpinBoxPage.cpp,v 2.3 2000/05/04 03:20:12 jeff Exp $

*******************************************************************************/


#include <qspinbox.h>
#include <qstring.h>

#include "SpinBoxPage.h"

#include "widget/DlgWidget.h"

#define Inherited SpinBoxPageData

SpinBoxPage::SpinBoxPage
(
    DlgWidget*	widget,
    QWidget* parent,
    const char* name
)
    :
    Inherited( parent, name )
{
    const QSpinBox* spinBox = static_cast<QSpinBox*> (widget->GetWidget());
    QString str;
    
    str.setNum( spinBox->minValue() );
    myMinValue->setText( str );
    
    str.setNum( spinBox->maxValue() );
    myMaxValue->setText( str );
    
    str.setNum( spinBox->lineStep() );
    myValueStep->setText( str );
    
    myPrefix->setText( spinBox->prefix() );
    
    mySuffix->setText( spinBox->suffix() );
    
    mySpecialValue->setText( spinBox->specialValueText() );
    
    switch( spinBox->buttonSymbols() )
    {
        case QSpinBox::UpDownArrows:
        {
            isButtonSymbolsArrows->setChecked( TRUE );
            break;
        }
        case QSpinBox::PlusMinus:
        {
            isButtonSymbolsPlusMinus->setChecked( TRUE );
            break;
        }
    }

    isWrapping->setChecked( spinBox->wrapping() );
}


SpinBoxPage::~SpinBoxPage()
{
}


void SpinBoxPage::Apply(
    DlgWidget*	theWidget
    )
{
    QSpinBox* spinBox = static_cast<QSpinBox*> (theWidget->GetWidget());
    
    QString str = myMinValue->text();
    QString str1 = myMaxValue->text();

    spinBox->setRange( str.toInt(), str1.toInt() );
    
    str = myValueStep->text();
    spinBox->setSteps( str.toInt(), spinBox->pageStep() );
    
    spinBox->setPrefix( myPrefix->text() );
    spinBox->setSuffix( mySuffix->text() );
    
    spinBox->setSpecialValueText( mySpecialValue->text() );
    
    QSpinBox::ButtonSymbols symbols = QSpinBox::UpDownArrows;
    if( isButtonSymbolsArrows->isChecked() )
    {
        symbols = QSpinBox::UpDownArrows;
    }
    else if( isButtonSymbolsPlusMinus->isChecked() )
    {
        symbols = QSpinBox::PlusMinus;
    }
    spinBox->setButtonSymbols( symbols );

    spinBox->setWrapping( isWrapping->isChecked() );
}
