/*******************************************************************************

    Qt Architect

    Copyright (C) 1997-1999 Jeff Harris and Klaus Ebner

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    $Id: WidgetColorPage.h,v 2.2 2000/04/30 17:09:44 jeff Exp $

*******************************************************************************/


#ifndef WidgetColorPage_included
#define WidgetColorPage_included

#include <qpalette.h>

#include "WidgetColorPageData.h"

class DlgWidget;

class WidgetColorPage : public WidgetColorPageData
{
    Q_OBJECT

public:

    WidgetColorPage
    (
	DlgWidget* widget,
        QWidget* parent = NULL,
        const char* name = NULL
    );

    virtual ~WidgetColorPage();

    void Apply( DlgWidget*	widget );
    // apply changes to the widget

private slots:

    virtual void GroupChanged( int );

    virtual void ColorClicked();

    virtual void FontClicked();

    virtual void SetPaletteClicked();

private:

    void ChangeColors( const QColorGroup&	colorGroup );
    // change the push buttons to the colors in the color group

    void SaveCurrentGroup( void );
    // save the current colors into the current color group in the palette

    void UpdateFontInfo( void );
    // update the font information based on itsFont

private:

    enum
    {
	Active,
        Inactive,
	Disabled,
    };

    int		itsCurrentGroup;

    QPalette	itsPalette;
    // palette for the widget

    bool	isCopy;
    // has the palette been copied from the widget

    bool	areColorsChanged;
    // have any of the colors been changed

    bool	isFontChanged;
    // has the font changed

    QFont	itsFont;
    // font for the widget

};
#endif // WidgetColorPage_included



