/*******************************************************************************

    Qt Architect

    Copyright (C) 1997-1999 Jeff Harris and Klaus Ebner

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    $Id: DlgButtonGroup.cpp,v 2.8 2000/05/04 03:20:15 jeff Exp $

*******************************************************************************/


#include "widget/DlgButtonGroup.h"

#include "prop/ButtonGroupPage.h"

#include "GuiTools.h"

#include "xml/QtArchExpat.h"
#include "xml/QtArchGenerator.h"

#define Inherited DlgGroupBox

QStrList DlgButtonGroup::itsSignals;
int DlgButtonGroup::itsNextWidgetNum = 1;

DlgButtonGroup::DlgButtonGroup() :
    Inherited( DlgWidget::DW_ButtonGroup )
{
}


DlgButtonGroup::DlgButtonGroup(
    DlgWidget::Type	theType
    ) :
    Inherited( theType )
{
}


DlgButtonGroup::~DlgButtonGroup()
{
}


void DlgButtonGroup::GetPropertyPages(
    QWidget*		parent,
    QList<QWidget>&	pages,
    QStrList&		labels
    )
{
    DlgFrame::GetPropertyPages( parent, pages, labels );

    pages.append( new ButtonGroupPage( this, parent, "ButtonGroup" ) );

    labels.append( tr( "Button Group" ) );
}


void DlgButtonGroup::Save( QtArchGenerator &generator )
{
  generator.WriteStartBlock( "ButtonGroup" );
                             
  QButtonGroup* widget = GetButtonGroup();

  generator.WriteXMLValue( "Exclusive", widget->isExclusive() );
  generator.WriteXMLValue( "RadioButtonExclusive", 
                           widget->isRadioButtonExclusive() );

  Inherited::Save( generator );

  generator.WriteEndBlock();
}


bool DlgButtonGroup::RestoreKeyValue( 
    const QString& 	key, 
    const QString& 	value,
    bool		topLevel
    )
{
    bool retVal = TRUE;

    if( topLevel )
    {
	if( key == "Name" )
	{
	    // Update the widget number so that no duplicate names are created
	    UpdateNextWidgetNumber( value, itsNextWidgetNum );
	}
    }

    QButtonGroup* widget = GetButtonGroup();

    // Compare to known keys
    if( key == "Exclusive" )
    {
	widget->setExclusive( (value == "TRUE") );
    } 
    else
    {
	retVal = Inherited::RestoreKeyValue( key, value, FALSE );
    }

    return retVal;
}

void DlgButtonGroup::RestoreXML( const XMLValue &value )
{
  // Sanity check
  if( value.GetTypeString() != "ButtonGroup" )
    return;

  const XMLValueMap map = value.AsNested();

  // Create if necessary
  if( ! GetButtonGroup() )
  {
    CreateQtWidget( 0 );
  }
  
  QButtonGroup* widget = GetButtonGroup();

  widget->setExclusive( map["Exclusive"].AsBool() );
  widget->setRadioButtonExclusive( map["RadioButtonExclusive"].AsBool() );
                        
  // We inherit from 
	Inherited::RestoreXML( map["GroupBox"] );

}


void DlgButtonGroup::GenerateSource(
    QTextStream&		stream,
    const QString&		varName,
    const WidgetLayout&         widgetLayout
    )
{
    Inherited::GenerateSource( stream, varName, widgetLayout );

    const QButtonGroup* widget = GetButtonGroup();

    stream << varName << "setExclusive( " <<
	(widget->isExclusive() ? "TRUE" : "FALSE") << " );\n";

    stream << varName << "setRadioButtonExclusive( " <<
	(widget->isRadioButtonExclusive() ? "TRUE" : "FALSE") << " );\n";
}


void DlgButtonGroup::AddSignalsToList( 
    QStrList&	signalList 
    ) const
{
    Inherited::AddSignalsToList( signalList );
    GuiTools::QStrListAppendAll( signalList, GetSignalList() );
}


const QStrList& DlgButtonGroup::GetSignalList()
{
    if( itsSignals.isEmpty() )
    {
	itsSignals.append( "pressed(int)" );
	itsSignals.append( "released(int)" );
	itsSignals.append( "clicked(int)" );
    }

    return itsSignals;
}


void DlgButtonGroup::CreateQtWidget(
    const char*	theName
    )
{
    QButtonGroup* widget = 
	new QButtonGroup( GetParent(),
			  CreateName( "ButtonGroup", 
				      theName, 
				      itsNextWidgetNum ) );

    SetQtWidget( widget );
}
