/*******************************************************************************

    Qt Architect

    Copyright (C) 1997-1999 Jeff Harris and Klaus Ebner

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    $Id: DlgComboBox.h,v 2.5 2000/04/29 20:15:49 klaus Exp $

*******************************************************************************/


#ifndef DlgComboBox_included
#define DlgComboBox_included

#include <qcombobox.h>
#include <qstring.h>
#include <qstrlist.h>

#include "widget/DlgWidget.h"

class DlgComboBox : public DlgWidget
{

public:

    DlgComboBox();
    // Constructor

    virtual ~DlgComboBox();
    // Destructor
    

    //
    // Saving and Loading Methods
    //

    virtual void Save( QtArchGenerator & );
    // save the contents of the widget

    virtual bool RestoreKeyValue( 
	const QString& 	key, 
	const QString& 	value,
	bool		topLevel = TRUE
	);
    // Restore a single key/value pair
    
    virtual void RestoreXML( const XMLValue & );
    // Restore a XMLValue


    //
    // Code Generation Methods
    //

    virtual QString GetHeaderFilename() const;
    // return the header filename for the widget

    virtual QString GetWidgetClass() const;
    // return the class name for the widget

    virtual void GenerateSource(
	QTextStream&		stream,
	const QString&		varName,
        const WidgetLayout&     widgetLayout
	);
    // Generate the source code needed to initialize the widget.
    // varName already has a leading tab and the correct dereferencer.

    virtual void GenerateCtor(
	QTextStream&		stream,
	const QString&		parentName
	);
    // output a constructor for the widget.  The
    // ctor for leaves the output at the start of the next line


    //
    // Property Editing Methods
    //

    virtual void GetPropertyPages(
	QWidget*		parent,
	QList<QWidget>&		pages,
	QStrList&		labels
	);
    // Get the property pages and their labels for the widget


    //
    // Connected Signals List
    //

    virtual void AddSignalsToList( 
	QStrList&	signalList
	) const;
    // add signals specific to a particular widget type to the list

    static const QStrList& GetSignalList();
    // method to return the list of signals

    //
    // Properties
    //

    enum ComboType
    {
	CT_ReadOnly,
	CT_ReadWrite,	
	CT_Motif1x
    };
    
    ComboType GetComboType() const;
    void SetComboType(
	ComboType	theType
	);

    bool AutoCompletion() const;

    void SetAutoCompletion(
	bool	theAutoCompletion
	);

protected: // Methods

    DlgComboBox(
	DlgWidget::Type	theType
	);
    // Constructor.  Used by a derived class' constructor.

    virtual void CreateQtWidget(
	const char*	theName
	);
    // Create and return the correct Qt widget for the specific type of
    // DlgWidget.


private: // Methods

    QComboBox* GetComboBox();
    // Get the Qt Widget as QComboBox.

private: // static data

    static QStrList	itsSignals;
    // list of the signals that can be connected to this widget

    static int itsNextWidgetNum;
    // number of the next widget

private:

    ComboType	myComboType;
    // The type of combo box.

    bool	isAutoCompletion;
    // Does the combo box do auto completion in read-write mode.
};


inline QString DlgComboBox::GetHeaderFilename() const
{
    return "<qcombobox.h>";
}

inline QString DlgComboBox::GetWidgetClass() const
{
    return "QComboBox";
}


inline DlgComboBox::ComboType DlgComboBox::GetComboType() const
{
    return myComboType;
}


inline void DlgComboBox::SetComboType(
    DlgComboBox::ComboType	theType
    )
{
    myComboType = theType;
}


inline bool DlgComboBox::AutoCompletion() const
{
    return isAutoCompletion;
}


inline void DlgComboBox::SetAutoCompletion(
    bool	theAutoCompletion
    )
{
    isAutoCompletion = theAutoCompletion;
}


inline QComboBox* DlgComboBox::GetComboBox()
{
    return static_cast<QComboBox*> (GetWidget());
}


#endif // DlgComboBox_included
