/*******************************************************************************

    Qt Architect

    Copyright (C) 1997-1999 Jeff Harris and Klaus Ebner

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    $Id: DlgFrame.cpp,v 2.9 2000/05/04 03:20:16 jeff Exp $

*******************************************************************************/


#include "widget/DlgFrame.h"

#include "prop/FramePage.h"

#include "GuiTools.h"

#include "xml/QtArchExpat.h"
#include "xml/QtArchGenerator.h"

#define Inherited DlgWidget

QStrList DlgFrame::itsSignals;
int DlgFrame::itsNextWidgetNum = 1;

DlgFrame::DlgFrame() :
    Inherited( DlgWidget::DW_Frame )
{
}


DlgFrame::DlgFrame(
    DlgWidget::Type	theType
    ) :
    Inherited( theType )
{
}


DlgFrame::~DlgFrame()
{
}


void DlgFrame::GetPropertyPages(
    QWidget*		parent,
    QList<QWidget>&	pages,
    QStrList&		labels
    )
{
    Inherited::GetPropertyPages( parent, pages, labels );

    pages.append( new FramePage( this, parent, "Frame" ) );

    labels.append( tr( "Frame" ) );
}

void DlgFrame::Save( QtArchGenerator &generator )
{
  generator.WriteStartBlock( "Frame" );

  QFrame* widget = GetFrame();

  generator.WriteXMLValue( "Style", widget->frameStyle() );
  generator.WriteXMLValue( "LineWidth", widget->lineWidth() );
  generator.WriteXMLValue( "MidLineWidth", widget->midLineWidth() );
  generator.WriteXMLValue( "FrameMargin", widget->margin() );

  Inherited::Save( generator );

  generator.WriteEndBlock();
}


bool DlgFrame::RestoreKeyValue( 
    const QString& 	key, 
    const QString& 	value,
    bool		topLevel
    )
{
    bool retVal = TRUE;

    if( topLevel )
    {
	if( key == "Name" )
	{
	    // Update the widget number so that no duplicate names are created
	    UpdateNextWidgetNumber( value, itsNextWidgetNum );
	}
    }

    QFrame* widget = GetFrame();

    // Compare to known keys
    if( key == "Style" )
    {
	widget->setFrameStyle( value.toInt() );
    } 
    else if( key == "LineWidth" )
    {
	widget->setLineWidth( value.toInt() );
    }
    else if( key == "MidLineWidth" )
    {
	widget->setMidLineWidth( value.toInt() );
    }
    else if( key == "FrameMargin" )
    {
	widget->setMargin( value.toInt() );
    }
    else
    {
	retVal = Inherited::RestoreKeyValue( key, value, FALSE );
    }

    return retVal;
}

void DlgFrame::RestoreXML( const XMLValue &value )
{
  // Sanity check
  if( value.GetTypeString() != "Frame" )
    return;

  const XMLValueMap map = value.AsNested();

  if( ! GetFrame() )
  {
    CreateQtWidget( 0 );
  }
  
  QFrame* widget = GetFrame();

  widget->setFrameStyle( map["Style"].AsInt() );
  widget->setLineWidth( map["LineWidth"].AsInt() );
  widget->setMidLineWidth( map["MidLineWidth"].AsInt() );
  widget->setMargin( map["FrameMargin"].AsInt() );
    
  // We inherit from Widget
	Inherited::RestoreXML( map["DlgWidget"] );

}


void DlgFrame::GenerateSource(
    QTextStream&		stream,
    const QString&		varName,
    const WidgetLayout&         widgetLayout
    )
{
    Inherited::GenerateSource( stream, varName, widgetLayout );

    const QFrame* widget = GetFrame();

    stream << varName <<
	"setFrameStyle( " << widget->frameStyle() << " );" << endl;
    
    stream << varName <<
	"setLineWidth( " << widget->lineWidth() << " );" << endl;
    
    stream << varName <<
	"setMidLineWidth( " << widget->midLineWidth() << " );" << endl;

    stream << varName <<
	"setMargin( " << widget->margin() << " );" << endl;
}


void DlgFrame::AddSignalsToList( 
    QStrList&	signalList 
    ) const
{
    Inherited::AddSignalsToList( signalList );
    GuiTools::QStrListAppendAll( signalList, GetSignalList() );
}


const QStrList& DlgFrame::GetSignalList()
{
    if( itsSignals.isEmpty() )
    {
    }

    return itsSignals;
}


void DlgFrame::CreateQtWidget(
    const char*	theName
    )
{
    QFrame* widget = 
	new QFrame( GetParent(),
		    CreateName( "Frame", 
				theName, 
				itsNextWidgetNum ) );

    SetQtWidget( widget );
}
