/*******************************************************************************

    Qt Architect

    Copyright (C) 1997-1999 Jeff Harris and Klaus Ebner

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    $Id: DlgSlider.h,v 2.6 2000/04/30 17:09:49 jeff Exp $

*******************************************************************************/


#ifndef DlgSlider_included
#define DlgSlider_included

#include <qslider.h>
#include <qstring.h>
#include <qstrlist.h>

#include "widget/DlgWidget.h"

class DlgSlider : public DlgWidget
{

public:

    DlgSlider();
    // Constructor

    virtual ~DlgSlider();
    // Destructor
    

    //
    // Saving and Loading Methods
    //

    virtual void Save( QtArchGenerator & );
    // save the contents of the widget

    virtual bool RestoreKeyValue( 
	const QString& 	key, 
	const QString& 	value,
	bool		topLevel = TRUE
	);
    // Restore a single key/value pair

    virtual void RestoreXML( const XMLValue & );
    // Restore a XMLValue


    //
    // Code Generation Methods
    //

    virtual QString GetHeaderFilename() const;
    // return the header filename for the widget

    virtual QString GetWidgetClass() const;
    // return the class name for the widget

    virtual void GenerateSource(
	QTextStream&		stream,
	const QString&		varName,
        const WidgetLayout&     widgetLayout
	);
    // Generate the source code needed to initialize the widget.
    // varName already has a leading tab and the correct dereferencer.


    //
    // Property Editing Methods
    //

    virtual void GetPropertyPages(
	QWidget*		parent,
	QList<QWidget>&		pages,
	QStrList&		labels
	);
    // Get the property pages and their labels for the widget


    //
    // Connected Signals List
    //

    virtual void AddSignalsToList( 
	QStrList&	signalList
	) const;
    // add signals specific to a particular widget type to the list

    static const QStrList& GetSignalList();
    // method to return the list of signals

    //
    // Utility methods
    //

    static QString TickSettingToStr( QSlider::Orientation       orient,
                                     QSlider::TickSetting       tick );
    // return a string value for the tick setting

    static QSlider::TickSetting StrToTickSetting( const QString& str );
    // return a tick setting for the string, default to NoMarks

protected: // Methods

    DlgSlider(
	DlgWidget::Type	theType
	);
    // Constructor.  Used by a derived class' constructor.

    virtual void CreateQtWidget(
	const char*	theName
	);
    // Create and return the correct Qt widget for the specific type of
    // DlgWidget.


private: // Methods

    QSlider* GetSlider();
    // Get the Qt Widget as QSlider.

private: // static data

    static QStrList	itsSignals;
    // list of the signals that can be connected to this widget

    static int itsNextWidgetNum;
    // number of the next widget

};


inline QString DlgSlider::GetHeaderFilename() const
{
    return "<qslider.h>";
}

inline QString DlgSlider::GetWidgetClass() const
{
    return "QSlider";
}


inline QSlider* DlgSlider::GetSlider()
{
    return static_cast<QSlider*> (GetWidget());
}


#endif // DlgSlider_included
