/*******************************************************************************

    Qt Architect

    Copyright (C) 1997-1999 Jeff Harris and Klaus Ebner

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    $Id: DlgVGroupBox.h,v 2.1 2000/04/30 17:09:49 jeff Exp $

*******************************************************************************/


#ifndef DlgVGroupBox_included
#define DlgVGroupBox_included

#include <qvgroupbox.h>
#include <qstring.h>
#include <qstrlist.h>

#include "widget/DlgGroupBox.h"

class DlgVGroupBox : public DlgGroupBox
{

public:

    DlgVGroupBox();
    // Constructor

    virtual ~DlgVGroupBox();
    // Destructor
    

    //
    // Saving and Loading Methods
    //

    virtual void Save( QtArchGenerator & );
    // save the contents of the widget

    virtual void RestoreXML( const XMLValue & );
    // Restore a XMLValue

    //
    // Code Generation Methods
    //

    virtual QString GetHeaderFilename() const;
    // return the header filename for the widget

    virtual QString GetWidgetClass() const;
    // return the class name for the widget

protected: // Methods

    DlgVGroupBox(
	DlgWidget::Type	theType
	);
    // Constructor.  Used by a derived class' constructor.

    virtual void CreateQtWidget(
	const char*	theName
	);
    // Create and return the correct Qt widget for the specific type of
    // DlgWidget.


private: // Methods

    QVGroupBox* GetVGroupBox();
    // Get the Qt Widget as QVGroupBox.

private: // static data

    static QStrList	itsSignals;
    // list of the signals that can be connected to this widget

    static int itsNextWidgetNum;
    // number of the next widget
};

inline QString DlgVGroupBox::GetHeaderFilename() const
{
    return "<qvgroupbox.h>";
}

inline QString DlgVGroupBox::GetWidgetClass() const
{
    return "QVGroupBox";
}


inline QVGroupBox* DlgVGroupBox::GetVGroupBox()
{
    return static_cast<QVGroupBox*> (GetWidget());
}


#endif // DlgVGroupBox_included
