/*******************************************************************************

    Qt Architect

    Copyright (C) 1997-1999 Jeff Harris and Klaus Ebner

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    $Id: SignalConnection.h,v 2.1 1999/10/16 01:51:36 jeff Exp $

*******************************************************************************/


#ifndef SignalConnection_included
#define SignalConnection_included

#include <qstring.h>

class SignalConnection
{
public:
  enum Scope
  {
    // no private since slots are declared in the dialog's base class,
    // and a private slot would not be visible by the dialog class
    BaseClass,
    Protected,
    Public
  };

  SignalConnection();

  SignalConnection( Scope		scope,
                    const QString&	signal,
                    const QString&	slot,
                    const QString&	args );

  QString ToString( void ) const;
  // convert the connection to a string to be placed in a list box for
  // display

  void FromString( const QString& from );
  // convert from the string to a SignalConnection

  SignalConnection::Scope GetScope( void ) const;
  void SetScope( SignalConnection::Scope scope );
    
  // get the signal string with arguments
  QString GetSignal( void ) const;
  // set both the signal and arguments from the string
  void SetSignal( const QString& sig );

  const QString& GetSignalName( void ) const;
  void SetSignalName( const QString& sig );
    
  // get the slot string with arguments
  const QString GetSlot( void ) const;

  const QString& GetSlotName( void ) const;
  void SetSlotName( const QString& slot );
    

private:
    
  Scope 	itsScope;

  QString	itsSignal;
  QString	itsSlot;
  QString	itsArgs;
};


inline SignalConnection::Scope SignalConnection::GetScope( void ) const
{
    return itsScope;
}


inline void SignalConnection::SetScope( SignalConnection::Scope scope )
{
    itsScope = scope;
}


inline const QString& SignalConnection::GetSignalName( void ) const
{
    return itsSignal;
}


inline void SignalConnection::SetSignalName( const QString& sig )
{
    itsSignal = sig;
}


inline const QString& SignalConnection::GetSlotName( void ) const
{
    return itsSlot;
}


inline void SignalConnection::SetSlotName( const QString& slot )
{
    itsSlot = slot;
}




#endif // SignalConnection_included
